@@ -78,20 +78,21 @@ def get_logger(
 LOGGER = get_logger('utilities')
 
 
-def create_symlink(from_filename: PathLike, to_filename: PathLike, overwrite: bool = False):
-    if not isinstance(from_filename, Path):
-        from_filename = Path(from_filename)
-    if not isinstance(to_filename, Path):
-        to_filename = Path(to_filename)
+def create_symlink(source_filename: PathLike, symlink_filename: PathLike):
+    if not isinstance(source_filename, Path):
+        source_filename = Path(source_filename)
+    if not isinstance(symlink_filename, Path):
+        symlink_filename = Path(symlink_filename)
 
-    if to_filename.exists() and overwrite:
-        os.remove(to_filename)
+    if symlink_filename.is_symlink():
+        LOGGER.info(f'removing symlink {symlink_filename}')
+        os.remove(symlink_filename)
 
     try:
-        to_filename.symlink_to(from_filename)
+        symlink_filename.symlink_to(source_filename)
     except Exception as error:
         LOGGER.warning(f'could not create symbolic link: {error}')
-        shutil.copyfile(from_filename, to_filename)
+        shutil.copyfile(source_filename, symlink_filename)
 
 
 def parse_datetime(value: Union[int, float, str, datetime]):
